sfs.fd
======

.. automodule:: sfs.fd

   
   
   .. rubric:: Functions

   .. autosummary::
   
      displacement
      secondary_source_line
      secondary_source_point
      shiftphase
      synthesize
   
   

   
   
   

   
   
   